JwtPayload class

Represents the payload content of a JWT token.

Constructors

JwtPayload({required String subject, required String email, required String name, required String issuer, required String audience, required DateTime notBefore, required DateTime expires, bool emailVerified = false, bool isVerified = false, String tenantId = '', String tid = '', List<String> permissions = const [], bool isAdministrator = false, Map<String, dynamic> extra = const <String, dynamic>{}})
const
JwtPayload.fromMap(Map<String, dynamic> map)
factory

Properties

audience → String
final
claimsMap → Map<String, dynamic>
no setter
email → String
final
emailVerified → bool
final
expires → DateTime
final
extra → Map<String, dynamic>
any other extra fields that are not represented in the available properties are stored in this property.
final
hashCode → int
The hash code for this object.
no setterinherited
isAdministrator → bool
final
issuer → String
final
isVerified → bool
final
name → String
final
notBefore → DateTime
final
permissions → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
final
tenantId → String
final
tid → String
final

Methods

copyWith({String? subject, String? email, String? name, String? issuer, String? audience, DateTime? notBefore, DateTime? expires, bool? emailVerified, bool? isVerified, String? tenantId, String? tid, bool? isAdministrator, List<String>? permissions, Map<String, dynamic>? extra}) → JwtPayload
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited